{% load i18n %}

<!-- OK Routes -->
{% translate "OK" as translated_header_green %}
{% translate "These routes are working as expected." as translated_header_green_explanation %}
{% include 'esistatus/partials/endpoints.html' with title=translated_header_green status="OK" explanation=translated_header_green_explanation data=esi_endpoint_status.OK with_details=True %}

<!-- Degraded Routes -->
{% translate "Degraded" as translated_header_yellow %}
{% translate "These routes have a good chance of being slow or returning errors." as translated_header_yellow_explanation %}
{% include 'esistatus/partials/endpoints.html' with title=translated_header_yellow status="Degraded" explanation=translated_header_yellow_explanation data=esi_endpoint_status.Degraded with_details=True %}

<!-- Down Routes -->
{% translate "Down" as translated_header_red %}
{% translate "These routes have a good chance of not responding at all or being completely unavailable." as translated_header_red_explanation %}
{% include 'esistatus/partials/endpoints.html' with title=translated_header_red status="Down" explanation=translated_header_red_explanation data=esi_endpoint_status.Down with_details=True %}

<!-- Recovering Routes -->
{% translate "Recovering" as translated_header_red %}
{% translate "These routes are recovering from previous issues and might not (yet) work as expected or might be slow." as translated_header_red_explanation %}
{% include 'esistatus/partials/endpoints.html' with title=translated_header_red status="Recovering" explanation=translated_header_red_explanation data=esi_endpoint_status.Recovering with_details=True %}
