<div id="esi-status-dashboard-panel" class="aa-esistatus col-12 mb-3 collapse"></div>

{% include "esistatus/svg/sprite.svg" %}

<script>
    const esistatusSettings = {
        dashboardWidget: {
            ajaxUrl: '{% url "esistatus:ajax_dashboard_widget" %}',
        }
    };
</script>

{% include "esistatus/bundles/esistatus-css.html" %}
{% include "esistatus/bundles/esistatus-dashboard-widget-js.html" %}
